Package: PKPDsim
Type: Package
Title: Tools for Performing Pharmacokinetic-Pharmacodynamic Simulations
Version: 1.4.1
Date: 2025-04-09
Authors@R: c(
        person("Ron", "Keizer", email = "ron@insight-rx.com", role = c("aut", "cre")),
        person("Jasmine", "Hughes", email = "jasmine@insight-rx.com", role = "aut"),
        person("Dominic", "Tong", email = "dominic@insight-rx.com", role = "aut"),
        person("Kara", "Woo", email = "kara@insight-rx.com", role = c("aut")),
        person("Jordan", "Brooks", email = "jordan.brooks@insight-rx.com", role = "aut"),
        person("InsightRX", role = c("cph", "fnd")))
Depends: R (>= 4.0.0)
Imports: Rcpp (>= 1.0.13), BH, data.table, stringr, MASS, randtoolbox,
        jsonlite, stats, parallel, magrittr
Suggests: httr, testthat (>= 3.0.0), mockery, knitr, rmarkdown
LinkingTo: BH, Rcpp (>= 1.0.13)
Description: Simulate dose regimens for pharmacokinetic-pharmacodynamic (PK-PD)
        models described by differential equation (DE) systems. Simulation using 
        ADVAN-style analytical equations is also supported (Abuhelwa et al. (2015) 
        <doi:10.1016/j.vascn.2015.03.004>).
License: MIT + file LICENSE
URL: https://github.com/InsightRX/PKPDsim,
        https://insightrx.github.io/PKPDsim/
Language: en-US
LazyData: TRUE
RoxygenNote: 7.3.2
Config/testthat/edition: 3
Config/Needs/website: tidyverse, nlmixr2
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2025-04-16 16:43:48 UTC; ronkeizer
Author: Ron Keizer [aut, cre],
  Jasmine Hughes [aut],
  Dominic Tong [aut],
  Kara Woo [aut],
  Jordan Brooks [aut],
  InsightRX [cph, fnd]
Maintainer: Ron Keizer <ron@insight-rx.com>
Repository: CRAN
Date/Publication: 2025-04-17 06:40:05 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 04:32:47 UTC; unix
Archs: PKPDsim.so.dSYM
