# Generated by roxygen2: do not edit by hand

S3method(print,PKPDsim)
S3method(print,covariate)
S3method(print,regimen)
S3method(print_list,"NULL")
S3method(print_list,list)
export(add_quotes)
export(add_ruv)
export(add_ruv_to_quantile)
export(adherence_binomial)
export(adherence_markov)
export(advan)
export(advan_create_data)
export(advan_parse_output)
export(advan_process_infusion_doses)
export(apply_duration_scale)
export(apply_lagtime)
export(available_default_literature_models)
export(calc_auc_analytic)
export(calc_ss_analytic)
export(calculate_parameters)
export(compile_sim_cpp)
export(covariate_last_obs_only)
export(covariates_table_to_list)
export(cv_to_omega)
export(detect_ode_syntax)
export(f_cov)
export(get_model_auc_compartment)
export(get_model_covariates)
export(get_model_fixed_parameters)
export(get_model_iov)
export(get_model_linearity)
export(get_model_parameters)
export(get_model_structure)
export(get_ode_model_size)
export(get_parameters_from_code)
export(get_var_y)
export(ifelse0)
export(install_default_literature_model)
export(is_positive_definite)
export(join_cov_and_par)
export(join_regimen)
export(merge_regimen)
export(model_from_api)
export(model_library)
export(mvrnorm2)
export(na_locf)
export(new_adherence)
export(new_covariate)
export(new_covariate_model)
export(new_ode_model)
export(new_regimen)
export(nlmixr_parse_parameters)
export(nm_to_regimen)
export(pkpdsim_to_nlmixr)
export(pop_regimen)
export(print_list)
export(read_model_json)
export(regimen_to_nm)
export(reparametrize)
export(search_replace_in_file)
export(shift_regimen)
export(sim)
export(sim_core)
export(sim_ode)
export(sim_ode_shiny)
export(table_to_list)
export(test_model)
export(test_pointer)
export(translate_ode)
export(triangle_to_full)
importFrom(Rcpp,sourceCpp)
importFrom(magrittr,`%>%`)
importFrom(stats,aggregate)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reshape)
importFrom(stats,rnorm)
importFrom(utils,packageVersion)
importFrom(utils,tail)
useDynLib(PKPDsim)
